pub enum MetadataVersion {
Show 14 variants
V0,
V1,
V2,
V3,
V4,
V5,
V6,
V7,
V8,
V9,
V10,
V11,
V12,
V13(MetadataV13),
}Expand description
Identifier of all the available Substrate metadata versions.
Variants
Implementations
Sourceimpl MetadataVersion
impl MetadataVersion
Sourcepub fn into_latest(self) -> Result<MetadataV13, Error>
pub fn into_latest(self) -> Result<MetadataV13, Error>
Consumes the object and returns the inner metadata structure, expecting the latest version. Results in an error if the version is not the latest.
Sourcepub fn version_number(&self) -> usize
pub fn version_number(&self) -> usize
Returns the version number as an integer.
pub fn into_inner(self) -> impl ModuleMetadataExt